==> sfml-2.6.0-3-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/all_9.js <==
var searchData=
[
  ['j_0',['J',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875aaf9b207522e37466a19f92b8dc836735',1,'sf::Keyboard::Scan::J'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a948c634009beacdab42c3419253a5e85',1,'sf::Keyboard::J']]],
  ['joystick_1',['Joystick',['../classsf_1_1Joystick.html',1,'sf']]],
  ['joystickbutton_2',['joystickButton',['../classsf_1_1Event.html#a42aad27a054c1c05bd5c3d020e1db174',1,'sf::Event']]],
  ['joystickbuttonevent_3',['JoystickButtonEvent',['../structsf_1_1Event_1_1JoystickButtonEvent.html',1,'sf::Event']]],
  ['joystickbuttonpressed_4',['JoystickButtonPressed',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa6d46855f0253f065689b69cd09437222',1,'sf::Event']]],
  ['joystickbuttonreleased_5',['JoystickButtonReleased',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa2246ef5ee33f7fa4b2a53f042ceeac3d',1,'sf::Event']]],
  ['joystickconnect_6',['joystickConnect',['../classsf_1_1Event.html#aa354335c9ad73362442bc54ffe81118f',1,'sf::Event']]],
  ['joystickconnected_7',['JoystickConnected',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aaabb8877ec2f0c92904170deded09321e',1,'sf::Event']]],
  ['joystickconnectevent_8',['JoystickConnectEvent',['../structsf_1_1Event_1_1JoystickConnectEvent.html',1,'sf::Event']]],
  ['joystickdisconnected_9',['JoystickDisconnected',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aab6e161dab7abaf154cc1c7b554558cb6',1,'sf::Event']]],
  ['joystickid_10',['joystickId',['../structsf_1_1Event_1_1JoystickConnectEvent.html#a08e58e8559d3e4fe4654855fec79194b',1,'sf::Event::JoystickConnectEvent::joystickId'],['../structsf_1_1Event_1_1JoystickMoveEvent.html#a7bf2b2f2941a21ed26a67c95f5e4232f',1,'sf::Event::JoystickMoveEvent::joystickId'],['../structsf_1_1Event_1_1JoystickButtonEvent.html#a2f80ecdb964a5ae0fc30726a404c41ec',1,'sf::Event::JoystickButtonEvent::joystickId']]],
  ['joystickmove_11',['joystickMove',['../classsf_1_1Event.html#ac479e8351cc2024d5c1094dc33970f7f',1,'sf::Event']]],
  ['joystickmoved_12',['JoystickMoved',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa4d6ad228485c135967831be16ec074dd',1,'sf::Event']]],
  ['joystickmoveevent_13',['JoystickMoveEvent',['../structsf_1_1Event_1_1JoystickMoveEvent.html',1,'sf::Event']]]
];

==> sfml-2.6.1-1-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/all_9.js <==
var searchData=
[
  ['j_0',['j',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875aaf9b207522e37466a19f92b8dc836735',1,'sf::Keyboard::Scan::J'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a948c634009beacdab42c3419253a5e85',1,'sf::Keyboard::J']]],
  ['joystick_1',['Joystick',['../classsf_1_1Joystick.html',1,'sf']]],
  ['joystickbutton_2',['joystickButton',['../classsf_1_1Event.html#a42aad27a054c1c05bd5c3d020e1db174',1,'sf::Event']]],
  ['joystickbuttonevent_3',['JoystickButtonEvent',['../structsf_1_1Event_1_1JoystickButtonEvent.html',1,'sf::Event']]],
  ['joystickbuttonpressed_4',['JoystickButtonPressed',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa6d46855f0253f065689b69cd09437222',1,'sf::Event']]],
  ['joystickbuttonreleased_5',['JoystickButtonReleased',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa2246ef5ee33f7fa4b2a53f042ceeac3d',1,'sf::Event']]],
  ['joystickconnect_6',['joystickConnect',['../classsf_1_1Event.html#aa354335c9ad73362442bc54ffe81118f',1,'sf::Event']]],
  ['joystickconnected_7',['JoystickConnected',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aaabb8877ec2f0c92904170deded09321e',1,'sf::Event']]],
  ['joystickconnectevent_8',['JoystickConnectEvent',['../structsf_1_1Event_1_1JoystickConnectEvent.html',1,'sf::Event']]],
  ['joystickdisconnected_9',['JoystickDisconnected',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aab6e161dab7abaf154cc1c7b554558cb6',1,'sf::Event']]],
  ['joystickid_10',['joystickid',['../structsf_1_1Event_1_1JoystickConnectEvent.html#a08e58e8559d3e4fe4654855fec79194b',1,'sf::Event::JoystickConnectEvent::joystickId'],['../structsf_1_1Event_1_1JoystickMoveEvent.html#a7bf2b2f2941a21ed26a67c95f5e4232f',1,'sf::Event::JoystickMoveEvent::joystickId'],['../structsf_1_1Event_1_1JoystickButtonEvent.html#a2f80ecdb964a5ae0fc30726a404c41ec',1,'sf::Event::JoystickButtonEvent::joystickId']]],
  ['joystickmove_11',['joystickMove',['../classsf_1_1Event.html#ac479e8351cc2024d5c1094dc33970f7f',1,'sf::Event']]],
  ['joystickmoved_12',['JoystickMoved',['../classsf_1_1Event.html#af41fa9ed45c02449030699f671331d4aa4d6ad228485c135967831be16ec074dd',1,'sf::Event']]],
  ['joystickmoveevent_13',['JoystickMoveEvent',['../structsf_1_1Event_1_1JoystickMoveEvent.html',1,'sf::Event']]]
];
